##  Step 6: Start a Survey Run
To send the survey to stakeholders and start collecting responses, initiate a survey run. Run the survey only for the fact sheet types on which you've created custom fields. To learn how to start a survey run, see [Sending Out a Survey](https://help.sap.com/docs/leanix/ea/sending-out-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Preview how the survey looks to the recipient, define the survey recipients based on fact sheet subscription roles, and compose an email invite to distribute the survey.").
The automation is triggered once a survey run is completed for a specific fact sheet.
**Note**
Because each new survey response overwrites the previous responses, you may want to send the survey only to a user with the Accountable subscription type who carries overall accountability for the fact sheet.
You can run the survey as often as you need. The fact sheet fields are updated accordingly on each completed survey run.
